@@ -97,6 +97,8 @@ public:
 	void patchbayPin();
 	void patchbayUnpin();
 
+	bool isPatchbayEmpty() const;
+
 	// Canvas methods.
 	void addItem(qpwgraph_item *item);
 	void removeItem(qpwgraph_item *item);
@@ -177,7 +179,7 @@ public:
 	void clear();
 
 	// Snap into position helper.
-	QPointF snapPos(qreal x, qreal y) const;
+	QPointF snapPos(const QPointF& pos) const;
 
 #ifdef CONFIG_CLEANUP_NODE_NAMES
 	static bool cleanupNodeName(QString& name);
@@ -187,6 +189,15 @@ public:
 	void setSearchPlaceholderText(const QString& text);
 	QString searchPlaceholderText() const;
 
+	// Filter/hide list management accessors.
+	void setFilterNodesEnabled(bool enabled);
+	bool isFilterNodesEnabled() const;
+
+	void setFilterNodesList(const QStringList& nodes);
+	const QStringList& filterNodesList() const;
+
+	bool isFilterNodes(const QString& node_name) const;
+
 signals:
 
 	// Node factory notifications.
@@ -293,9 +304,6 @@ protected:
 	const QRectF& boundingRect(bool reset = false);
 	void boundingPos(QPointF& pos);
 
-	// Snap into position helper.
-	void snapPos(QPointF& pos) const;
-
 	// Start search editor...
 	void startSearchEditor(const QString& text = QString());
 
@@ -354,6 +362,10 @@ private:
 
 	// Item search stuff.
 	QLineEdit *m_search_editor;
+
+	// Filter/hide list management.
+	bool        m_filter_enabled;
+	QStringList m_filter_nodes;
 };
 
 
