@@ -28,6 +28,8 @@
 #include <QMainWindow>
 #include <QFileInfo>
 
+#include <QComboBox>
+
 
 // Local constants.
 static const char *GeometryGroup    = "/GraphGeometry";
@@ -60,6 +62,7 @@ static const char *PatchbayQueryQuitKey = "/QueryQuit";
 static const char *SystemTrayGroup  = "/SystemTray";
 static const char *SystemTrayEnabledKey = "/Enabled";
 static const char *SystemTrayQueryCloseKey = "/QueryClose";
+static const char *SystemTrayStartMinimizedKey = "/StartMinimized";
 #endif
 
 #ifdef CONFIG_ALSA_MIDI
@@ -70,6 +73,12 @@ static const char *AlsaMidiEnabledKey = "/Enabled";
 static const char *SessionGroup = "/Session";
 static const char *SessionStartMinimizedKey = "/StartMinimized";
 
+static const char *FilterNodesGroup = "/FilterNodes";
+static const char *FilterNodesEnabledKey = "/Enabled";
+static const char *FilterNodesListKey = "/List";
+
+static const char *HistoryGroup = "/History";
+
 
 // Legacy main-form class renaming support (> v0.7.7)
 #define LEGACY_MAIN_FORM 1
@@ -95,8 +104,13 @@ qpwgraph_config::qpwgraph_config ( QSettings *settings, bool owner )
 		m_patchbay_exclusive(false),
 		m_patchbay_autopin(true),
 		m_patchbay_autodisconnect(false),
+		m_patchbay_queryquit(false),
+		m_systray_queryclose(false),
 		m_systray_enabled(true),
-		m_alsaseq_enabled(true)
+		m_alsaseq_enabled(true),
+		m_start_minimized(false),
+		m_filter_enabled(false),
+		m_filter_dirty(false)
 {
 }
 
@@ -388,6 +402,50 @@ bool qpwgraph_config::isAlsaMidiEnabled (void) const
 }
 
 
+void qpwgraph_config::setStartMinimized ( bool start_minimized )
+{
+	m_start_minimized = start_minimized;
+}
+
+bool qpwgraph_config::isStartMinimized (void) const
+{
+	return m_start_minimized;
+}
+
+
+void qpwgraph_config::setFilterNodesEnabled ( bool enabled )
+{
+	m_filter_enabled = enabled;
+}
+
+bool qpwgraph_config::isFilterNodesEnabled (void) const
+{
+	return m_filter_enabled;
+}
+
+
+void qpwgraph_config::setFilterNodesList ( const QStringList& nodes )
+{
+	m_filter_nodes = nodes;
+}
+
+const QStringList& qpwgraph_config::filterNodesList (void) const
+{
+	return m_filter_nodes;
+}
+
+
+void qpwgraph_config::setFilterNodesDirty ( bool dirty )
+{
+	m_filter_dirty = dirty;
+}
+
+bool qpwgraph_config::isFilterNodesDirty (void) const
+{
+	return m_filter_dirty;
+}
+
+
 void qpwgraph_config::setSessionStartMinimized ( bool start_minimized )
 {
 	m_settings->beginGroup(SessionGroup);
@@ -414,10 +472,16 @@ bool qpwgraph_config::restoreState ( QMainWindow *widget )
 	if (m_settings == nullptr || widget == nullptr)
 		return false;
 
+	m_settings->beginGroup(FilterNodesGroup);
+	m_filter_enabled = m_settings->value(FilterNodesEnabledKey, false).toBool();
+	m_filter_nodes = m_settings->value(FilterNodesListKey).toStringList();
+	m_settings->endGroup();
+
 #ifdef CONFIG_SYSTEM_TRAY
 	m_settings->beginGroup(SystemTrayGroup);
 	m_systray_enabled = m_settings->value(SystemTrayEnabledKey, true).toBool();
 	m_systray_queryclose = m_settings->value(SystemTrayQueryCloseKey, true).toBool();
+	m_start_minimized = m_settings->value(SystemTrayStartMinimizedKey, false).toBool();
 	m_settings->endGroup();
 #endif
 
@@ -509,10 +573,16 @@ bool qpwgraph_config::saveState ( QMainWindow *widget ) const
 	if (m_settings == nullptr || widget == nullptr)
 		return false;
 
+	m_settings->beginGroup(FilterNodesGroup);
+	m_settings->setValue(FilterNodesEnabledKey, m_filter_enabled);
+	m_settings->setValue(FilterNodesListKey, m_filter_nodes);
+	m_settings->endGroup();
+
 #ifdef CONFIG_SYSTEM_TRAY
 	m_settings->beginGroup(SystemTrayGroup);
 	m_settings->setValue(SystemTrayEnabledKey, m_systray_enabled);
 	m_settings->setValue(SystemTrayQueryCloseKey, m_systray_queryclose);
+	m_settings->setValue(SystemTrayStartMinimizedKey, m_start_minimized);
 	m_settings->endGroup();
 #endif
 
@@ -561,4 +631,44 @@ bool qpwgraph_config::saveState ( QMainWindow *widget ) const
 }
 
 
+// Combo box history persistence helpers.
+//
+void qpwgraph_config::loadComboBoxHistory ( QComboBox *cbox, int nlimit )
+{
+	m_settings->beginGroup(HistoryGroup);
+	if (m_settings->childKeys().count() > 0) {
+		const QStringList& items
+			= m_settings->value('/' + cbox->objectName()).toStringList();
+		if (!items.isEmpty()) {
+			const bool block_signals
+				= cbox->blockSignals(true);
+			cbox->setUpdatesEnabled(false);
+			cbox->setDuplicatesEnabled(false);
+			cbox->clear();
+			cbox->addItems(items);
+			cbox->setUpdatesEnabled(true);
+			cbox->blockSignals(block_signals);
+		}
+	}
+	m_settings->endGroup();
+
+}
+
+
+void qpwgraph_config::saveComboBoxHistory ( QComboBox *cbox, int nlimit )
+{
+	int ncount = cbox->count();
+	if (ncount > nlimit)
+		ncount = nlimit;
+
+	QStringList items;
+	for (int i = 0; i < ncount; ++i)
+		items.append(cbox->itemText(i));
+
+	m_settings->beginGroup(HistoryGroup);
+	m_settings->setValue('/' + cbox->objectName(), items);
+	m_settings->endGroup();
+}
+
+
 // end of qpwgraph_config.cpp
