@@ -1,7 +1,7 @@
 // qpwgraph_pipewire.h
 //
 /****************************************************************************
-   Copyright (C) 2021-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2021-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -72,6 +72,7 @@ public:
 	// PipeWire port types.
 	static uint audioPortType();
 	static uint midiPortType();
+	static uint midi2PortType();
 	static uint videoPortType();
 	static uint otherPortType();
 
@@ -103,6 +104,7 @@ public:
 	Node *createNode(
 		uint node_id,
 		const QString& node_name,
+		const QString& node_nick,
 		qpwgraph_item::Mode node_mode,
 		uint node_type);
 	void destroyNode(Node *node);
